@@ -8,6 +8,8 @@ import avro.schema
 from confluent_kafka import Producer, Consumer, KafkaError
 from confluent_kafka.admin import AdminClient, NewTopic, NewPartitions
 
+from eslogger import Logger
+
 
 class MessageException(Exception):
     def __init__(self, m):
@@ -22,19 +24,41 @@ class EventManager:
         self.producerClient = Producer({
             "bootstrap.servers": "127.0.0.1:9092"
         })
+        self.log = Logger('event-manager')
 
     def create_address(self, address: str):
         if address not in self.adminClient.list_topics().topics:
-            self.adminClient.create_topics([NewTopic(address, 1, 1)])
+            fs = self.adminClient.create_topics([NewTopic(address, 1, 1)])
+            for topic, f in fs.items():
+                try:
+                    f.result()  # The result itself is None
+                    self.log.info("Topic {} created".format(topic))
+                except Exception as e:
+                    self.log.error("Failed to create topic {}: {}".format(topic, e))
 
     def modify_mailbox_size(self, address: str, size: int):
         if address in self.adminClient.list_topics().topics:
-            self.adminClient.create_partitions([NewPartitions(address, size)])
+            fs = self.adminClient.create_partitions([NewPartitions(address, size)])
+            for topic, f in fs.items():
+                try:
+                    f.result()  # The result itself is None
+                    self.log.info("Additional partitions created for topic {}".format(topic))
+                except Exception as e:
+                    self.log.error("Failed to add partitions to topic {}: {}".format(topic, e))
+            return fs
 
     def delete_address(self, address: str):
         if address not in self.adminClient.list_topics().topics:
-            raise MessageException(f"Address {address} was not found")
-        self.adminClient.delete_topics([address])
+            self.log.warning(f"Address {address} was not found")
+            return
+        fs = self.adminClient.delete_topics([address])
+        # Wait for operation to finish.
+        for topic, f in fs.items():
+            try:
+                f.result()  # The result itself is None
+                self.log.info("Topic {} deleted".format(topic))
+            except Exception as e:
+                self.log.error("Failed to delete topic {}: {}".format(topic, e))
 
     @staticmethod
     def send_command_to_address(address: str, schema_str: str, command_object: object):
@@ -54,8 +78,7 @@ class EventManager:
         except ValueError:
             print(f"Error Invalid input {command_object}, discarding record...")
 
-    @staticmethod
-    def wait_for_command(address: str, schema_str: str, on):
+    def wait_for_command(self, address: str, schema_str: str, on):
 
         conf = {'bootstrap.servers': "127.0.0.1:9092",
                 'group.id': 'command.query',
@@ -73,11 +96,11 @@ class EventManager:
                     continue
                 if msg.error():
                     if msg.error().code() == KafkaError._PARTITION_EOF:
-                        print('ERROR: %% %s [%d] reached end at offset %d\n' %
-                              (msg.topic(), msg.partition(),
-                               msg.offset()))
+                        self.log.error('ERROR: %% %s [%d] reached end at offset %d\n' %
+                                       (msg.topic(), msg.partition(),
+                                        msg.offset()))
                     elif msg.error():
-                        print(f"ERROR: {msg.error()}")
+                        self.log.error(f"ERROR: {msg.error()}")
                 else:
                     message = msg.value()
                     bytes_reader = io.BytesIO(message)
@@ -89,10 +112,10 @@ class EventManager:
                         # x = threading.Thread(target=on, args=(decoded_msg,))
                         # x.start()
                     except AssertionError as e:
-                        print(f"ERROR: {e}")
+                        self.log.error(f"ERROR: {e}")
 
         except Exception as e:
-            print(f"Stopped polling for address {address}. Error: {e}")
+            self.log.error(f"Stopped polling for address {address}. Error: {e}")
 
 
 if __name__ == "__main__":
